==> xlniuxdata-vipgame-1.0.0-20141225.035105-5-sources.jar: com/xunlei/niux/data/vipgame/vo/tasks/TaskGameConfig.java <==
package com.xunlei.niux.data.vipgame.vo.tasks;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by jamesjxin on 14-6-10.
 */
@Table(tableName = "taskgameconfig",pkFieldAssign = false,pkFieldName = "seqId")
public class TaskGameConfig {
    private Long seqId;
    private String gameId;
    private String picUrl;
    private Integer showOrder;
    private Integer task1ref;
    private Integer task2ref;
    private Integer task3ref;
    private Integer task4ref;

    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public Integer getShowOrder() {
        return showOrder;
    }

    public void setShowOrder(Integer showOrder) {
        this.showOrder = showOrder;
    }

    public Integer getTask1ref() {
        return task1ref;
    }

    public void setTask1ref(Integer task1ref) {
        this.task1ref = task1ref;
    }

    public Integer getTask2ref() {
        return task2ref;
    }

    public void setTask2ref(Integer task2ref) {
        this.task2ref = task2ref;
    }

    public Integer getTask3ref() {
        return task3ref;
    }

    public void setTask3ref(Integer task3ref) {
        this.task3ref = task3ref;
    }

    public Integer getTask4ref() {
        return task4ref;
    }

    public void setTask4ref(Integer task4ref) {
        this.task4ref = task4ref;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }
}

==> xlniuxdata-vipgame-1.0.53-20160309.074345-6-sources.jar: com/xunlei/niux/data/vipgame/vo/tasks/TaskGameConfig.java <==
package com.xunlei.niux.data.vipgame.vo.tasks;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by jamesjxin on 14-6-10.
 */
@Table(tableName = "taskgameconfig",pkFieldAssign = false,pkFieldName = "seqId")
public class TaskGameConfig {
    private Long seqId;
    private String gameId;
    private String picUrl;
    private Integer showOrder;
    private Integer task1ref;
    private Integer task2ref;
    private Integer task3ref;
    private Integer task4ref;
    private Boolean isRecommend;

    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public Integer getShowOrder() {
        return showOrder;
    }

    public void setShowOrder(Integer showOrder) {
        this.showOrder = showOrder;
    }

    public Integer getTask1ref() {
        return task1ref;
    }

    public void setTask1ref(Integer task1ref) {
        this.task1ref = task1ref;
    }

    public Integer getTask2ref() {
        return task2ref;
    }

    public void setTask2ref(Integer task2ref) {
        this.task2ref = task2ref;
    }

    public Integer getTask3ref() {
        return task3ref;
    }

    public void setTask3ref(Integer task3ref) {
        this.task3ref = task3ref;
    }

    public Integer getTask4ref() {
        return task4ref;
    }

    public void setTask4ref(Integer task4ref) {
        this.task4ref = task4ref;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public Boolean getIsRecommend() {
        return isRecommend;
    }

    public void setIsRecommend(Boolean isRecommend) {
        this.isRecommend = isRecommend;
    }
}
